@@ -9,23 +9,28 @@
 #' @param x Vector of taxa names (character) or IDs (character or numeric)
 #' to query.
 #' @param db character; database to query. One or more of `itis`,
-#' `col`, `ncbi`, or `worms`. Note that each taxonomic data
+#' `ncbi`, `worms`, or `bold`. Note that each taxonomic data
 #' source has their own identifiers, so that if you provide the wrong
 #' `db` value for the identifier you could get a result, but it will
 #' likely be wrong (not what you were expecting). If using ncbi, we recommend
 #' getting an API key; see [taxize-authentication]
 #' @param rows (numeric) Any number from 1 to infinity. If the default NA, all
 #' rows are considered. Note that this parameter is ignored if you pass in a
-#' taxonomic id of any of the acceptable classes: tsn, colid. NCBI has a
+#' taxonomic id of any of the acceptable classes: tsn. NCBI has a
 #' method for this function but rows doesn't work.
-#' @param ... Further args passed on to [col_children()],
-#' [ritis::hierarchy_down()], [ncbi_children()], or [worrms::wm_children()].
+#' @param ... Further args passed on to [ritis::hierarchy_down()],
+#' [ncbi_children()], [worrms::wm_children()], [bold_children()]
 #' See those functions for what parameters can be passed on.
 #'
 #' @section ncbi:
 #' note that with `db = "ncbi"`, we set `ambiguous = TRUE`; that is, children
 #' taxa with words like "unclassified", "unknown", "uncultured", "sp." are
 #' NOT removed
+#' 
+#' @section bold:
+#' BEWARE: `db="bold"` scrapes the BOLD website, so may be unstable. That is,
+#' one day it may work, and the next it may fail. Open an issue if you
+#' encounter an error: https://github.com/ropensci/taxize/issues
 #'
 #' @return A named list of data.frames with the children names of every
 #' supplied taxa. You get an NA if there was no match in the database.
@@ -34,46 +39,37 @@
 #' # Plug in taxonomic IDs
 #' children(161994, db = "itis")
 #' children(8028, db = "ncbi")
-#' children("578cbfd2674a9b589f19af71a33b89b6", db = "col")
 #' ## works with numeric if as character as well
-#' children("161994", db = "itis")
+#' children(161994, db = "itis")
+#' children(88899, db = "bold")
+#' children(as.boldid(88899))
 #'
 #' # Plug in taxon names
-#' children("Salmo", db = 'col')
 #' children("Salmo", db = 'itis')
 #' children("Salmo", db = 'ncbi')
 #' children("Salmo", db = 'worms')
+#' children("Salmo", db = 'bold')
 #'
 #' # Plug in IDs
-#' (id <- get_colid("Apis"))
-#' children(id)
-#'
 #' (id <- get_wormsid("Platanista"))
 #' children(id)
 #'
-#' ## Equivalently, plug in the call to get the id via e.g., get_colid
-#' ## into children
-#' (id <- get_colid("Apis"))
-#' children(id)
-#' children(get_colid("Apis"))
-#'
 #' # Many taxa
 #' sp <- c("Tragia", "Schistocarpha", "Encalypta")
-#' children(sp, db = 'col')
 #' children(sp, db = 'itis')
 #'
 #' # Two data sources
-#' (ids <- get_ids("Apis", db = c('col','itis')))
+#' (ids <- get_ids("Apis", db = c('ncbi','itis')))
 #' children(ids)
 #' ## same result
-#' children(get_ids("Apis", db = c('col','itis')))
+#' children(get_ids("Apis", db = c('ncbi','itis')))
 #'
 #' # Use the rows parameter
-#' children("Poa", db = 'col')
-#' children("Poa", db = 'col', rows=1)
+#' children("Poa", db = 'itis')
+#' children("Poa", db = 'itis', rows=1)
 #'
 #' # use curl options
-#' res <- children("Poa", db = 'col', rows=1, verbose = TRUE)
+#' res <- children("Poa", db = 'itis', rows=1, verbose = TRUE)
 #' }
 
 children <- function(...){
@@ -91,11 +87,6 @@ children.default <- function(x, db = NULL, rows = NA, ...) {
       stats::setNames(children(id, ...), x)
     },
 
-    col = {
-      id <- process_children_ids(x, db, get_colid, rows = rows, ...)
-      stats::setNames(children(id, ...), x)
-    },
-
     ncbi = {
       if (all(grepl("^[[:digit:]]*$", x))) {
         id <- x
@@ -112,6 +103,12 @@ children.default <- function(x, db = NULL, rows = NA, ...) {
       stats::setNames(children(id, ...), x)
     },
 
+    bold = {
+      id <- process_children_ids(as.character(x), db, get_boldid,
+        rows = rows, ...)
+      stats::setNames(children(id, ...), x)
+    },
+
     stop("the provided db value was not recognised", call. = FALSE)
   )
 
@@ -127,7 +124,7 @@ itis_blank <- data.frame(
   tsn        = character(0),
   stringsAsFactors = FALSE
 )
-worms_blank <- col_blank <- ncbi_blank <-
+worms_blank <- ncbi_blank <- bold_blank <-
   data.frame(
     childtaxa_id     = character(0),
     childtaxa_name   = character(0),
@@ -139,12 +136,9 @@ set_output_types <- function(x, x_names, db){
   blank_fun <- switch(
     db,
     itis  = function(w) if (nrow(w) == 0 || all(is.na(w))) itis_blank else w,
-    col   = function(w) {
-      if (inherits(w, "list")) w <- w[[1]]
-      if (nrow(w) == 0 || all(is.na(w))) col_blank else w
-    },
     ncbi  = function(w) if (nrow(w) == 0 || all(is.na(w))) ncbi_blank else w,
-    worms = function(w) if (nrow(w) == 0 || all(is.na(w))) worms_blank else w
+    worms = function(w) if (nrow(w) == 0 || all(is.na(w))) worms_blank else w,
+    bold = function(w) if (nrow(w) == 0 || all(is.na(w))) bold_blank else w
   )
 
   typed_results <- lapply(seq_along(x), function(i) blank_fun(x[[i]]))
@@ -155,8 +149,9 @@ set_output_types <- function(x, x_names, db){
 
 process_children_ids <- function(input, db, fxn, ...){
   g <- tryCatch(as.numeric(as.character(input)), warning = function(e) e)
-  if (is(g, "numeric") || is.character(input) && grepl("[[:digit:]]", input)) {
-    as_fxn <- switch(db, itis = as.tsn, col = as.colid, worms = as.wormsid)
+  if (inherits(g, "condition")) eval(fxn)(input, ...)
+  if (is.numeric(g) || is.character(input) && all(grepl("[[:digit:]]", input))) {
+    as_fxn <- switch(db, itis = as.tsn, worms = as.wormsid, bold = as.boldid)
     as_fxn(input, check = FALSE)
   } else {
     eval(fxn)(input, ...)
@@ -182,28 +177,6 @@ children.tsn <- function(x, db = NULL, ...) {
   return(out)
 }
 
-#' @export
-#' @rdname children
-children.colid <- function(x, db = NULL, ...) {
-  warn_db(list(db = db), "col")
-  fun <- function(y){
-    # return NA if NA is supplied
-    if (is.na(y)) {
-      out <- NA
-    } else {
-      out <- col_children(id = y, ...)
-    }
-    return(out)
-  }
-  out <- lapply(x, fun)
-  if (length(out) == 1) {
-    out = out[[1]]
-  }
-  class(out) <- 'children'
-  attr(out, 'db') <- 'col'
-  return(out)
-}
-
 df2dt2tbl <- function(x) {
   tibble::as_tibble(
     data.table::setDF(
@@ -275,3 +248,17 @@ children.uid <- function(x, db = NULL, ...) {
   attr(out, 'db') <- 'ncbi'
   return(out)
 }
+
+#' @export
+#' @rdname children
+children.boldid <- function(x, db = NULL, ...) {
+  warn_db(list(db = db), "bold")
+  out <- if (is.na(x)) {
+    stats::setNames(list(bold_blank), x)
+  } else {
+    bold_children(id = x, ...)
+  }
+  class(out) <- 'children'
+  attr(out, 'db') <- 'bold'
+  return(out)
+}
