@@ -39,11 +39,6 @@
 #' comm2sci('blue whale', db = "worms")
 #' comm2sci(c('blue whale', 'dwarf surfclam'), db = "worms")
 #'
-#' # Output easily converts to a data.frame with plyr::ldply
-#' library(plyr)
-#' ldply(comm2sci(commnames=c('annual blue grass','tree of heaven'),
-#'   db='tropicos'))
-#'
 #' # ncbi: pass in uid's from get_uid() directly
 #' x <- get_uid("western capercaillie", modifier = "Common Name")
 #' comm2sci(x)
@@ -150,7 +145,7 @@ c2s_ncbi <- function(x, simplify, ...) {
   # common name
   out <- xml_text(xml_find_all(ttp, "//TaxaSet/Taxon/ScientificName"))
   # NCBI limits requests to three per second
-  if (is.null(key)) Sys.sleep(0.34)
+  ncbi_rate_limit_pause(key)
   return(out)
 }
 
