@@ -3,7 +3,7 @@
 #' @export
 #' @param sciname (character) one or more scientific names. Or, a `taxon_state`
 #' object (see [taxon-state])
-#' @param ask logical; should get_colid be run in interactive mode?
+#' @param ask logical; should get_gbifid be run in interactive mode?
 #' If TRUE and more than one ID is found for the species, the user is asked for
 #' input. If FALSE NA is returned for multiple matches.
 #' @param messages logical; If TRUE the actual taxon queried is printed on the console.
@@ -309,7 +309,7 @@ as.data.frame.gbifid <- function(x, ...){
              stringsAsFactors = FALSE)
 }
 
-make_gbifid <- function(x, check=TRUE) make_generic(x, 'http://www.gbif.org/species/%s', "gbifid", check)
+make_gbifid <- function(x, check=TRUE) make_generic(x, 'https://www.gbif.org/species/%s', "gbifid", check)
 
 check_gbifid <- function(x){
   tryid <- tryCatch(gbif_name_usage(key = x), error = function(e) e)
