@@ -27,19 +27,18 @@
 #' @examples \dontrun{
 #' if (requireNamespace("vegan", quietly = TRUE)) {
 #'   # use dune dataset
-#'   library("vegan")
 #'   data(dune, package='vegan')
-#'   species <- c("Bellis perennis", "Empetrum nigrum", "Juncus bufonius",
-#'   "Juncus articulatus",
-#'   "Aira praecox", "Eleocharis parvula", "Rumex acetosa", "Vicia lathyroides",
-#'   "Brachythecium rutabulum", "Ranunculus flammula", "Cirsium arvense",
-#'   "Hypochaeris radicata", "Leontodon autumnalis", "Potentilla palustris",
-#'   "Poa pratensis", "Calliergonella cuspidata", "Trifolium pratense",
-#'   "Trifolium repens", "Anthoxanthum odoratum", "Salix repens", "Achillea
-#'   millefolium",
-#'   "Poa trivialis", "Chenopodium album", "Elymus repens", "Sagina procumbens",
-#'   "Plantago lanceolata", "Agrostis stolonifera", "Lolium perenne", "Alopecurus
-#'   geniculatus", "Bromus hordeaceus")
+#'   species <- c("Achillea millefolium", "Agrostis stolonifera",
+#'     "Aira praecox", "Alopecurus geniculatus", "Anthoxanthum odoratum",
+#'     "Bellis perennis", "Bromus hordeaceus", "Chenopodium album",
+#'     "Cirsium arvense", "Comarum palustre", "Eleocharis palustris",
+#'     "Elymus repens", "Empetrum nigrum", "Hypochaeris radicata",
+#'     "Juncus articulatus", "Juncus bufonius", "Lolium perenne",
+#'     "Plantago lanceolata", "Poa pratensis", "Poa trivialis",
+#'     "Ranunculus flammula", "Rumex acetosa", "Sagina procumbens",
+#'     "Salix repens", "Scorzoneroides autumnalis", "Trifolium pratense",
+#'     "Trifolium repens", "Vicia lathyroides", "Brachythecium rutabulum",
+#'     "Calliergonella cuspidata")
 #'   colnames(dune) <- species
 #'
 #'   # aggregate sample to families
@@ -55,7 +54,7 @@
 #' spnames <- c('Puma','Ursus americanus','Ursidae')
 #' df <- data.frame(c(1,2,3), c(11,12,13), c(1,4,50))
 #' names(df) <- spnames
-#' out <- tax_agg(df, rank = 'family', db='itis')
+#' out <- tax_agg(x=df, rank = 'family', db='itis')
 #' out$x
 #'
 #' # You can input a matrix too
@@ -72,8 +71,9 @@ tax_agg <- function(x, rank, db = 'ncbi', messages=FALSE, ...)
     x <- data.frame(x, check.names = FALSE)
   }
   # bring to long format
+  # df_m <- data.table::melt(x)
   x$rownames <- rownames(x)
-  df_m <- melt(x, id = 'rownames')
+  df_m <- setDF(suppressWarnings(data.table::melt(as.data.table(x))))
 
   # aggregate to family level (by querying NCBI for taxonomic classification)
   uniq_tax <- as.character(unique(df_m$variable))
@@ -87,8 +87,8 @@ tax_agg <- function(x, rank, db = 'ncbi', messages=FALSE, ...)
   df_merged$agg <- ifelse(is.na(df_merged$agg), df_merged$variable, df_merged$agg)
 
   # bring back to long format and aggregate
-  df_l <- dcast(df_merged, rownames ~ agg,
-                value.var = 'value', fun.aggregate = sum)
+  df_l <- setDF(data.table::dcast(as.data.table(df_merged),
+    rownames ~ agg, value.var = 'value', fun.aggregate = sum))
 
   rownames(df_l) <- df_l$rownames
   df_l$rownames <- NULL
