@@ -3,7 +3,9 @@ context("get_eolid")
 test_that("get_eolid works", {
   skip_on_cran()
 
-  a <- get_eolid(sciname = "Puma concolor", messages = FALSE, rows = 1)
+  vcr::use_cassette("get_eolid", {
+    a <- get_eolid(sciname = "Puma concolor", messages = FALSE, rows = 1)
+  })
 
   expect_is(a, "eolid")
   expect_is(a[[1]], "character")
@@ -14,33 +16,15 @@ test_that("get_eolid works", {
   expect_true(attr(a, "multiple_matches"))
   expect_true(attr(a, "pattern_match"))
   expect_is(attr(a, "uri"), "character")
-
-  Sys.sleep(3)
 })
 
-test_that("get_eolid returns the correct value", {
-  skip_on_cran()
-
-  expect_true(is.na(get_eolid(sciname = 'adsf asdf asdf',
-    messages = FALSE)[[1]]))
-  Sys.sleep(3)
-})
-
-test_that("get_eolid returns the correct class", {
-  skip_on_cran()
-
-  expect_that(get_eolid("adsf asdf asdf", messages=FALSE),
-              is_a("eolid"))
-  Sys.sleep(1)
-})
-
-Sys.sleep(1)
-
 test_that("get_eolid accepts ask-argument", {
   skip_on_cran()
 
-  expect_true(is.na(get_eolid(sciname = 'adsf asdf asdf', ask = FALSE,
-    messages = FALSE)[[1]]))
+  vcr::use_cassette("get_eolid_ask_param", {
+    expect_true(is.na(get_eolid(sciname = 'adsf asdf asdf', ask = FALSE,
+      messages = FALSE)[[1]]))
+  })
 })
 
 test_that("get_eolid fails as expected", {
