@@ -1,13 +1,11 @@
 context("get_natservid")
 
 test_that("get_natservid returns the correct value", {
-  if (Sys.getenv('NATURE_SERVE_KEY') == "") {
-    skip("No NatureServe api key so test not run.")
-  }
+  skip_on_cran()
 
   vcr::use_cassette("get_natservid", {
-    x <- get_natservid(c('Gadus morhua', "howdy"), messages=FALSE)[2]
-    w <- get_natservid(c("Helianthus annuus", 'Gadus morhua'), 
+    x <- get_natservid(c('Pomatomus saltatrix', "howdy"), messages=FALSE)[2]
+    w <- get_natservid(c("Helianthus annuus", 'Pomatomus saltatrix'), 
         messages=FALSE)
   })
     
@@ -16,12 +14,10 @@ test_that("get_natservid returns the correct value", {
 })
 
 test_that("get_natservid accepts ask-argument", {
-  if (Sys.getenv('NATURE_SERVE_KEY') == "") {
-    skip("No NatureServe api key so test not run.")
-  }
-
+  skip_on_cran()
+  
   vcr::use_cassette("get_natservid_ask_arg", {
-    x <- get_natservid('asdasf', ask = FALSE, messages=FALSE)
+    x <- get_natservid('howdy', ask = FALSE, messages=FALSE)
   })
 
   expect_true(is.na(x))
@@ -30,10 +26,6 @@ test_that("get_natservid accepts ask-argument", {
 test_that("get_natservid fails well", {
   skip_on_cran()
 
-  if (Sys.getenv('NATURE_SERVE_KEY') == "") {
-    skip("No NatureServe api key so test not run.")
-  }
-
   expect_true(is.na(get_natservid("asdfadsf", messages = FALSE)))
 
   expect_error(get_natservid(), "argument \"query\" is missing")
